( cd usr/openwin/lib ; rm -rf openwin-menu )
( cd usr/openwin/lib ; ln -sf /var/openwin/lib/openwin-menu openwin-menu )
( cd usr/include ; rm -rf olgx )
( cd usr/include ; ln -sf /usr/openwin/include/olgx olgx )
( cd usr/include ; rm -rf pixrect )
( cd usr/include ; ln -sf /usr/openwin/include/pixrect pixrect )
( cd usr/include ; rm -rf xview )
( cd usr/include ; ln -sf /usr/openwin/include/xview xview )
( cd usr/include ; rm -rf uit )
( cd usr/include ; ln -sf /usr/openwin/include/uit uit )
( cd usr/lib ; rm -rf .text_extras_menu )
( cd usr/lib ; ln -sf /usr/openwin/lib/.text_extras_menu .text_extras_menu )
( cd usr/X11R6/bin ; rm -rf openwin )
( cd usr/X11R6/bin ; ln -sf /usr/openwin/bin/openwin openwin )
